pub struct SimilarityLowerBoundRule { /* private fields */ }Expand description
Applies the similarity lower bound of DL8.5: stops when the bound reaches the upper bound, and makes the node a leaf when its error already meets the bound.
Implementations