Heuristic

Trait Heuristic 

pub trait Heuristic: Send + Sync {
    // Required method
    fn compute(
        &self,
        cover: &mut Cover,
        candidates: &mut Vec<usize>,
    ) -> Vec<f64>;

    // Provided method
    fn compute_with_scorer(
        &self,
        parent_entropy: f64,
        cover: &mut Cover,
        candidates: &mut Vec<usize>,
        scorer: Box<dyn Fn(&[usize], &[usize], &[usize], f64) -> f64>,
        lower_is_better: bool,
    ) -> Vec<f64> { ... }
}
Ranks candidate features at a node.

Required Methods

fn compute(&self, cover: &mut Cover, candidates: &mut Vec<usize>) -> Vec<f64>

Sorts candidates best first and returns their scores in the same order (empty when the heuristic does not score).

Provided Methods

fn compute_with_scorer( &self, parent_entropy: f64, cover: &mut Cover, candidates: &mut Vec<usize>, scorer: Box<dyn Fn(&[usize], &[usize], &[usize], f64) -> f64>, lower_is_better: bool, ) -> Vec<f64>

Scores each candidate with scorer and sorts them, ascending when lower_is_better and descending otherwise.