pub struct DecreasingTopkRule { /* private fields */ }Expand description
Like TopkRule, but the number of features allowed halves at each
level: k / 2^depth, and at least one.
Implementations
Sourceimpl DecreasingTopkRule
impl DecreasingTopkRule
Sourcepub fn new(limit: usize, increment: Box<dyn StepStrategy>) -> Self
pub fn new(limit: usize, increment: Box<dyn StepStrategy>) -> Self
A rule whose root k grows following increment, up to limit.
Sourcepub fn with_delay(self, delay: u8) -> Self
pub fn with_delay(self, delay: u8) -> Self
Sets the number of passes before the rule takes effect.
Sourcepub fn with_budget(self, budget: usize) -> Self
pub fn with_budget(self, budget: usize) -> Self
Sets k for the first pass.