pub struct ExampleParser {Show 14 fields
pub input: PathBuf,
pub support: usize,
pub depth: usize,
pub timeout: f64,
pub metric: f64,
pub epsilon: f64,
pub fast_d2: OptimalDepth2Policy,
pub print_stats: bool,
pub always_sort: bool,
pub heuristic: SearchHeuristic,
pub step: SearchStepStrategy,
pub result: PathBuf,
pub print_tree: bool,
pub overwrite: bool,
}Expand description
Command line arguments of the anytime examples.
Fields
input: PathBufDataset file: one instance per line, label first, binary features
support: usizeMinimum number of instances in each leaf
depth: usizeMaximum depth of the tree
timeout: f64Time limit in seconds
metric: f64Not used by the current examples
epsilon: f64Step of the gain and purity rules
fast_d2: OptimalDepth2PolicyWhether to use the depth-2 solver
print_stats: boolPrint the search statistics
always_sort: boolSort the features by the heuristic at every node
heuristic: SearchHeuristicHeuristic used to order the features
step: SearchStepStrategyHow the budget of the search rule grows between passes
result: PathBufDirectory where the JSON results are written
print_tree: boolPrint the tree
overwrite: boolOverwrite existing results